@@ -42,6 +42,7 @@ from preservationdatabase.models import (
     LastFill,
     ISSN,
     ISSNL,
+    InternetArchiveItem,
 )
 
 from django.db import transaction
@@ -70,7 +71,7 @@ def import_portico(url, local):
 @click.option(
     "--file",
     default="ia_sim_keepers_kbart.2022-12-12.tsv",
-    help="The filename of the Hathitrust full dump to use",
+    help="The filename of the Internet Archive full dump to use",
 )
 @click.option(
     "--bucket",
@@ -80,13 +81,24 @@ def import_portico(url, local):
 @click.option("--local", is_flag=True, default=False)
 @transaction.atomic()
 def import_internet_archive(file, bucket, local):
-    """Import data from Hathi (requires local file download or S3)"""
+    """Import data from Internet Archive (requires local file download or S3)"""
     s3client = boto3.client("s3")
     InternetArchivePreservation.import_data(
         file, bucket=bucket, s3client=s3client, local=local
     )
 
 
+@click.command()
+@click.option(
+    "--file",
+    default="release_export_expanded.json",
+    help="The filename of the Internet Archive release_export_expanded to use",
+)
+def import_internet_archive_items(file):
+    """Import item data from Internet Archive"""
+    InternetArchiveItem.import_data(file)
+
+
 @click.command()
 @click.option(
     "--url",
@@ -417,6 +429,7 @@ if __name__ == "__main__":
     cli.add_command(import_clockss)
     cli.add_command(import_hathi)
     cli.add_command(import_internet_archive)
+    cli.add_command(import_internet_archive_items)
     cli.add_command(import_issnl)
     cli.add_command(import_lockss)
     cli.add_command(import_ocul)
