@@ -17,28 +17,33 @@ def setup_environment(code_bucket, download_settings=True) -> None:
     from rich.logging import RichHandler
 
     logging.basicConfig(
-        level=logging.INFO, format="%(message)s", datefmt="[%X]",
-        handlers=[RichHandler(console=Console(stderr=True))]
+        level=logging.INFO,
+        format="%(message)s",
+        datefmt="[%X]",
+        handlers=[RichHandler(console=Console(stderr=True))],
     )
     log = logging.getLogger("rich")
     log.setLevel(logging.INFO)
 
     current_directory = os.path.dirname(
-        os.path.abspath(inspect.getfile(inspect.currentframe())))
+        os.path.abspath(inspect.getfile(inspect.currentframe()))
+    )
 
     if download_settings:
-        settings_file = Path(current_directory) / 'downloaded_settings.py'
+        settings_file = Path(current_directory) / "downloaded_settings.py"
 
-        logging.info('Settings file downloading to: '
-                     '{}'.format(settings_file))
+        logging.info(
+            "Settings file downloading to: " "{}".format(settings_file)
+        )
 
         import boto3
-        s3client = boto3.client('s3')
-        s3client.download_file(code_bucket, 'settings.py', str(settings_file))
+
+        s3client = boto3.client("s3")
+        s3client.download_file(code_bucket, "settings.py", str(settings_file))
 
     sys.path.append(current_directory)
-    os.environ.setdefault('DJANGO_SETTINGS_MODULE',
-                          'downloaded_settings')
+    os.environ.setdefault("DJANGO_SETTINGS_MODULE", "downloaded_settings")
 
     import django
+
     django.setup()
