@@ -7,6 +7,7 @@ import datetime
 from datetime import datetime as dt
 from io import StringIO
 from pathlib import Path
+from time import sleep
 
 import pytz
 from django.db import models, transaction
@@ -1150,3 +1151,97 @@ class InternetArchivePreservation(models.Model):
                         f"{InternetArchivePreservation.name()} data "
                         f"({len(volumes)} volumes)"
                     )
+
+
+class InternetArchiveItem(models.Model):
+    class Meta:
+        db_table = "preservationData_iaitems"
+
+        indexes = [
+            models.Index(fields=["doi"]),
+            models.Index(fields=["fatcat_ident"]),
+        ]
+
+    doi = models.TextField()
+    url = models.TextField()
+    fatcat_ident = models.TextField()
+
+    @staticmethod
+    def import_data(file: str) -> None:
+        """Imports data from an Internet Archive file. Updates are propagated
+        in batches of 1000.
+
+        :param file: the file to import from
+        :return None
+        """
+        from rich.progress import track
+        from rich.progress import Progress
+
+        from msgspec.json import decode
+        from msgspec import Struct
+        from typing import Optional
+
+        class URL(Struct):
+            url: str
+            rel: str
+
+        class Files(Struct):
+            urls: list[URL]
+
+        class Identifier(Struct):
+            doi: Optional[str] = None
+
+        class IAItem(Struct):
+            ident: str
+            ext_ids: Identifier
+            files: list[Files]
+
+        file_size = Path(file).stat().st_size
+
+        with Progress() as progress:
+            with open(file, "rb") as f:
+                task = progress.add_task("[red]Importing...", total=file_size)
+
+                count = 0
+                batch_objects = []
+
+                utils.clear_out(InternetArchiveItem)
+
+                for json_data in f:
+                    data = decode(json_data, type=IAItem)
+
+                    list_comp = [
+                        (data, x)
+                        for file in data.files
+                        for x in file.urls
+                        if x.rel == "webarchive"
+                        and data.ext_ids.doi is not None
+                    ]
+
+                    progress.update(task, advance=len(json_data))
+
+                    for outcome, url in list_comp:
+                        # print(f"{url}, {outcome.ext_ids.doi},
+                        # {outcome.ident}")
+
+                        batch_objects.append(
+                            InternetArchiveItem(
+                                doi=outcome.ext_ids.doi,
+                                url=url,
+                                fatcat_ident=outcome.ident,
+                            )
+                        )
+
+                        count += 1
+
+                    if count == 1000:
+                        InternetArchiveItem.objects.bulk_create(batch_objects)
+                        logging.info(f"Flushing {len(batch_objects)} items.")
+                        count = 0
+                        batch_objects = []
+
+                # flush the final objects
+                InternetArchiveItem.objects.bulk_create(batch_objects)
+                logging.info(f"Flushing {len(batch_objects)} items.")
+
+            return
