@@ -10,20 +10,61 @@ from random import randint
 
 import django
 import requests
-from crossref.restful import Etiquette, Works
+from crossref.restful import Etiquette, Journals, Works
 from django.db import transaction
 from django.db.models import QuerySet, Count
 
 from lxml import etree as ET
 
 
+def expand_issns(issn) -> set:
+    """
+    Expands a list of ISSNs using the ISSNL lookup database.
+    :param issn: the list of ISSNs to expand
+    :return: a set of expanded ISSNs
+    """
+    from preservationdatabase.models import ISSN, ISSNL
+
+    final_issn_list = []
+
+    for issn_item in issn:
+        final_issn_list.append(issn_item)
+        issn_objs = ISSN.objects.filter(identifier=issn_item)
+        issnl_objs = ISSNL.objects.filter(identifier=issn_item)
+
+        for issn_obj in issn_objs:
+            issnl_objs = ISSNL.objects.filter(
+                identifier=issn_obj.issnl.identifier
+            )
+
+            for issnl_obj in issnl_objs:
+                issn_reversed = ISSN.objects.filter(issnl=issnl_obj)
+
+                for issn_reversed_obj in issn_reversed:
+                    final_issn_list.append(issn_reversed_obj.identifier)
+
+        for issn_reversed in issnl_objs:
+            final_issn_list.append(issn_reversed.identifier)
+
+            issn_objs = ISSN.objects.filter(issnl=issn_reversed)
+
+            for issn_obj in issn_objs:
+                final_issn_list.append(issn_obj.identifier)
+
+    final_issn_list = set(final_issn_list)
+
+    return final_issn_list
+
+
 def show_preservation(
     container_title: str,
-    issn: str,
+    issn: set,
     volume: str,
     no: str | None,
     doi: str,
     archive: str = None,
+    year: str | None = None,
+    no_issn: bool = False,
 ) -> (dict | None, str):
     """
     Determine whether an item is preserved
@@ -32,31 +73,21 @@ def show_preservation(
     :param volume: the volume
     :param no: the number
     :param doi: the DOI
+    :param no_issn: if true, will not look up ISSNs for expansion
+    :param year: the year
     :param archive: the archive to query (or None for all archives)
     :return: a dictionary of preservations and a doi
     """
     from preservationdatabase import constants
-    from preservationdatabase.models import ISSN, ISSNL
 
     # extend ISSNs
     issn = set(issn)
 
     # extend the ISSN using the ISSNL lookup table
-    final_issn_list = []
-
-    for issn_item in issn:
-        final_issn_list.append(issn_item)
-        issn_objs = ISSN.objects.filter(identifier=issn_item)
-
-        for issn_obj in issn_objs:
-            issnl_obj = ISSNL.objects.filter(identifier=issn_obj.issnl)
-
-            issn_reversed = ISSN.objects.filter(issnl=issn_obj.issnl)
-
-            for reversed in issn_reversed:
-                final_issn_list.append(reversed.identifier)
-
-    final_issn_list = set(final_issn_list)
+    if no_issn:
+        final_issn_list = issn
+    else:
+        final_issn_list = expand_issns(issn)
 
     if issn != final_issn_list:
         logging.info(
@@ -72,7 +103,7 @@ def show_preservation(
 
     for system in preservation_systems:
         preserved, done = system.preservation(
-            container_title, final_issn_list, volume, no
+            container_title, final_issn_list, volume, no, year
         )
         preservations[system.name()] = preserved, done
 
@@ -95,17 +126,15 @@ def unpack_range(s: str) -> list:
 
 
 def show_preservation_for_doi(
-    doi_input: str, archive: str = None
+    doi_input: str, archive: str = None, no_issn: bool = False
 ) -> (dict | None, str):
     """
     Determine whether a DOI is preserved with resolution via the REST API
     :param doi_input: the DOI to look up
+    :param no_issn: if true, will not look up ISSNs for expansion
     :param archive: the archive to query (or None for all archives)
     :return:
     """
-    # TODO: caching
-    # TODO: tests
-    # TODO: type hints
 
     my_etiquette = Etiquette(
         "Preservation Status", "0.01", "https://eve.gd", "meve@crossref.org"
@@ -131,8 +160,21 @@ def show_preservation_for_doi(
         f"({issns}) v{volume} n{no}"
     )
 
+    year = None
+    # "published": {"date-parts": [[2005, 12, 30]]}}}
+
+    if "published" in doi:
+        year = doi["published"]["date-parts"][0][0]
+
     preserves, doi_echo = show_preservation(
-        container_title, issns, volume, no, doi, archive
+        container_title,
+        issns,
+        volume,
+        no,
+        doi,
+        archive,
+        year=year,
+        no_issn=no_issn,
     )
 
     # the "archive" field is apparently returned if deposited
@@ -528,11 +570,12 @@ def normalize_issn(issn) -> str:
 
 
 @transaction.atomic
-def random_db_entries(model, count) -> list:
+def random_db_entries(model, count, only_crossref=False) -> list:
     """
     Returns random entries from a database model
     :param model: the model to use
     :param count: the number of random entries to return
+    :param only_crossref: whether to only return crossref entries
     :return: a list of random entries
     """
 
@@ -542,9 +585,46 @@ def random_db_entries(model, count) -> list:
 
     total = model.objects.all().count()
 
-    for i in range(0, count - 1):
+    my_etiquette = Etiquette(
+        "Preservation Status", "0.01", "https://eve.gd", "meve@crossref.org"
+    )
+
+    jrnls = Journals(etiquette=my_etiquette)
+
+    while len(output) < count - 1:
         random_index = randint(0, total - 1)
-        output.append(model.objects.all()[random_index])
+
+        entry = model.objects.all()[random_index]
+
+        if only_crossref:
+            append = False
+
+            new_issns = expand_issns([entry.issn])
+
+            for issn in new_issns:
+                jrnl = jrnls.journal(issn=issn)
+
+                if jrnl:
+                    append = True
+                    break
+
+            if hasattr(entry, "eissn"):
+                new_eissns = expand_issns([entry.eissn])
+
+                for issn in new_eissns:
+                    jrnl = jrnls.journal(issn=issn)
+
+                    if jrnl:
+                        append = True
+                        break
+
+            if append:
+                output.append(entry)
+                print(
+                    "Found crossref entry ({}): {}".format(len(output), entry)
+                )
+        else:
+            output.append(entry)
 
     return output
 
